@@ -104,7 +104,7 @@ pub struct PyConfig {
     pub use_hash_seed: c_int,
     pub hash_seed: c_ulong,
     pub faulthandler: c_int,
-    #[cfg(Py_3_9)]
+    #[cfg(all(Py_3_9, not(Py_3_10)))]
     pub _use_peg_parser: c_int,
     pub tracemalloc: c_int,
     pub import_time: c_int,
@@ -117,12 +117,17 @@ pub struct PyConfig {
     pub filesystem_errors: *mut wchar_t,
     pub pycache_prefix: *mut wchar_t,
     pub parse_argv: c_int,
+    #[cfg(Py_3_10)]
+    pub orig_argv: PyWideStringList,
     pub argv: PyWideStringList,
+    #[cfg(not(Py_3_10))]
     pub program_name: *mut wchar_t,
     pub xoptions: PyWideStringList,
     pub warnoptions: PyWideStringList,
     pub site_import: c_int,
     pub bytes_warning: c_int,
+    #[cfg(Py_3_10)]
+    pub warn_default_encoding: c_int,
     pub inspect: c_int,
     pub interactive: c_int,
     pub optimization_level: c_int,
@@ -139,8 +144,12 @@ pub struct PyConfig {
     pub legacy_windows_stdio: c_int,
     pub check_hash_pycs_mode: *mut wchar_t,
     pub pathconfig_warnings: c_int,
+    #[cfg(Py_3_10)]
+    pub program_name: *mut wchar_t,
     pub pythonpath_env: *mut wchar_t,
     pub home: *mut wchar_t,
+    #[cfg(Py_3_10)]
+    pub platlibdir: *mut wchar_t,
     pub module_search_paths_set: c_int,
     pub module_search_paths: PyWideStringList,
     pub executable: *mut wchar_t,
@@ -149,7 +158,7 @@ pub struct PyConfig {
     pub base_prefix: *mut wchar_t,
     pub exec_prefix: *mut wchar_t,
     pub base_exec_prefix: *mut wchar_t,
-    #[cfg(Py_3_9)]
+    #[cfg(all(Py_3_9, not(Py_3_10)))]
     pub platlibdir: *mut wchar_t,
     pub skip_source_first_line: c_int,
     pub run_command: *mut wchar_t,
@@ -159,7 +168,7 @@ pub struct PyConfig {
     pub _init_main: c_int,
     #[cfg(Py_3_9)]
     pub _isolated_interpreter: c_int,
-    #[cfg(Py_3_9)]
+    #[cfg(all(Py_3_9, not(Py_3_10)))]
     pub _orig_argv: PyWideStringList,
 }
 
