@@ -2,7 +2,10 @@ use libc::c_int;
 
 use crate::object::*;
 
-pub enum PyWeakReference {}
+#[repr(C)]
+pub struct PyWeakReference {
+    _private: [u8; 0],
+}
 
 #[cfg_attr(windows, link(name = "pythonXY"))]
 extern "C" {
